@@ -32,16 +32,16 @@ from piptools.utils import (
     make_install_requirement,
 )
 
-from .constants import MINIMAL_WHEELS_PATH
+from .constants import MINIMAL_WHEELS_PATH, TEST_DATA_PATH
 from .utils import looks_like_ci
 
 
 class FakeRepository(BaseRepository):
     def __init__(self):
-        with open("tests/test_data/fake-index.json") as f:
+        with open(os.path.join(TEST_DATA_PATH, "fake-index.json")) as f:
             self.index = json.load(f)
 
-        with open("tests/test_data/fake-editables.json") as f:
+        with open(os.path.join(TEST_DATA_PATH, "fake-editables.json")) as f:
             self.editables = json.load(f)
 
     def get_hashes(self, ireq):
